==> apache-seata-2.4.0-incubating-src.tar.gz: apache-seata-2.4.0-incubating-src/server/src/main/java/org/apache/seata/server/logging/logback/ExtendedArrowThrowableProxyConverter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.seata.server.logging.logback;

import ch.qos.logback.classic.pattern.ExtendedThrowableProxyConverter;
import ch.qos.logback.classic.spi.IThrowableProxy;

/**
 * {@link ExtendedThrowableProxyConverter} that adds some additional whitespace around the
 * stack trace.
 */
public class ExtendedArrowThrowableProxyConverter extends ExtendedThrowableProxyConverter {

    public static final String SEPARATOR = System.getProperty("line.separator");
    public static final String START_ARROW = "==> ";
    public static final String END_ARROW = " <==";
    @Override
    protected String throwableProxyToString(IThrowableProxy tp) {
        StringBuilder throwBuilder = new StringBuilder();
        throwBuilder.append(START_ARROW)
            .append(SEPARATOR)
            .append(super.throwableProxyToString(tp))
            .append(END_ARROW)
            .append(SEPARATOR);
        return throwBuilder.toString();
    }

}

==> apache-seata-2.5.0-incubating-src.tar.gz: apache-seata-2.5.0-incubating-src/server/src/main/java/org/apache/seata/server/logging/logback/ExtendedArrowThrowableProxyConverter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.seata.server.logging.logback;

import ch.qos.logback.classic.pattern.ExtendedThrowableProxyConverter;
import ch.qos.logback.classic.spi.IThrowableProxy;

/**
 * {@link ExtendedThrowableProxyConverter} that adds some additional whitespace around the
 * stack trace.
 */
public class ExtendedArrowThrowableProxyConverter extends ExtendedThrowableProxyConverter {

    public static final String SEPARATOR = System.getProperty("line.separator");
    public static final String START_ARROW = "==> ";
    public static final String END_ARROW = " <==";

    @Override
    protected String throwableProxyToString(IThrowableProxy tp) {
        StringBuilder throwBuilder = new StringBuilder();
        throwBuilder
                .append(START_ARROW)
                .append(SEPARATOR)
                .append(super.throwableProxyToString(tp))
                .append(END_ARROW)
                .append(SEPARATOR);
        return throwBuilder.toString();
    }
}
